/**
 * @file
 * jQuery code.
 * Based on code: Adrian "yEnS" Mato Gondelle, twitter: @adrianmg
 * Modifications for Drupal: Grzegorz Bartman grzegorz.bartman@openbit.pl
 */


// Setting up popup.
// 0 means disabled; 1 means enabled.
var popupStatus = 0;

/**
 * Loading popup with jQuery.
 */
function popup_message_load_popup() {
  // Loads popup only if it is disabled.
  if (popupStatus == 0) {
    jQuery("#backgroundPopup").css( {
      "opacity": "0.7"
    });
    jQuery("#backgroundPopup").fadeIn("slow");
    jQuery("#popupContact").fadeIn("slow");
    popupStatus = 1;
  }
}

/**
 * Disabling popup with jQuery.
 */
function popup_message_disable_popup() {
  // Disables popup only if it is enabled.
  if (popupStatus == 1) {
    jQuery("#backgroundPopup").fadeOut("slow");
    jQuery("#popupContact").fadeOut("slow");
    popupStatus = 0;
  }
}

/**
 * Centering popup.
 */
function popup_message_center_popup(width, height) {
  // Request data for centering.
  var windowWidth = document.documentElement.clientWidth;
  var windowHeight = document.documentElement.clientHeight;

  var popupWidth = 0
  if (typeof width == "undefined") {
    popupWidth = $("#popupContact").width();
  }
  else {
    popupWidth = width;
  }
  var popupHeight = 0
  if (typeof width == "undefined") {
    popupHeight = $("#popupContact").height();
  }
  else {
    popupHeight = height;
  }

  // Centering.
  jQuery("#popupContact").css( {
    "position": "absolute",
    "top": windowHeight / 2 - popupHeight / 2,
    "left": windowWidth / 2 - popupWidth / 2,
    "width": popupWidth,
    "height": popupHeight
  });
  // Only need force for IE6.
  jQuery("#backgroundPopup").css( {
    "height": windowHeight
  });

}

/**
 * Display popup message.
 */
function popup_message_display_popup(popup_message_title, popup_message_body, width, height) {
  jQuery('body').append('<div id="popupContact"><a id="popupContactClose">X</a>\n\
    <h1>' + popup_message_title + '</h1><p id="contactArea">' + popup_message_body
    + '</div><div id="backgroundPopup"></div>');

  // Loading popup.
  popup_message_center_popup(width, height);
  popup_message_load_popup();

  // Closing popup.
  // Click the x event!
  jQuery("#popupContactClose").click(function() {
    popup_message_disable_popup();
  });
  // Click out event!
  jQuery("#backgroundPopup").click(function() {
    popup_message_disable_popup();
  });
  // Press Escape event!
  jQuery(document).keypress(function(e) {
    if (e.keyCode == 27 && popupStatus == 1) {
      popup_message_disable_popup();
    }
  });
}

/**
 * Helper function for get last element from object.
 * Used if on page is loaded more than one message.
 */
function popup_message_get_last_object_item(variable_data) {
  if (typeof(variable_data) == 'object') {
      variable_data = variable_data[(variable_data.length - 1)];
  }
  return variable_data;
}

Drupal.behaviors.popup_message = {
  attach: function(context) {
    var check_cookie = Drupal.settings.popup_message.check_cookie;
    check_cookie = popup_message_get_last_object_item(check_cookie);
    var popup_message_cookie = jQuery.cookie("popup_message_displayed");
    if (popup_message_cookie != 1 || check_cookie == false) {
      // Set cookie.
      jQuery.cookie("popup_message_displayed", 1, {
        path: '/'
      });

      // Get variables.
      var popup_message_title = Drupal.settings.popup_message.title;
      var popup_message_body = Drupal.settings.popup_message.body;
      var popup_message_width = Drupal.settings.popup_message.width;
      var popup_message_height = Drupal.settings.popup_message.height;
      popup_message_title = popup_message_get_last_object_item(popup_message_title);
      popup_message_body = popup_message_get_last_object_item(popup_message_body);
      popup_message_width = popup_message_get_last_object_item(popup_message_width);
      popup_message_height = popup_message_get_last_object_item(popup_message_height);
      // Display message.
      popup_message_display_popup(popup_message_title, popup_message_body,
        popup_message_width, popup_message_height)
    }
  }
};
